from urllib.parse import urlparse
import urllib.request
from selenium import webdriver
from selenium.webdriver.chrome.service import Service
from selenium.webdriver.chrome.options import Options
from abc import ABC, abstractmethod


class Downloader(ABC):

    def __init__(self):
        pass

    @abstractmethod
    def download(self, url):
        pass

class SimpleDownloader(Downloader):

    def __init__(self):
        super().__init__()


    def download(self, url):
        print("Downloading {}".format(url))

        try:
            resource = urllib.request.urlopen(url)
            data = resource.read().decode(resource.headers.get_content_charset())
            return data
        except:
            return None



class ChromiumHeadlessDownloader(Downloader):

    def __init__(self):
        super().__init__()
        self.options = Options()
        self.options.add_argument("--headless=new")
        self.options.add_argument("--disable-dev-shm-usage")
        self.options.add_argument("--no-sandbox")
        self.service = Service("/usr/bin/chromedriver")


    def download(self, url):
        print("Download {}".format(url))
        self.driver = webdriver.Chrome(service=self.service, options=self.options)

        self.driver.get(url)
        doc = self.driver.page_source
        self.driver.quit()
        return doc
