import os

from .downloader import *
from .extractor import *


class URL2Events:

    def __init__(self, downloader = SimpleDownloader(), extractor = None, single_event=False):

        self.downloader = downloader
        self.extractor = extractor
        self.single_event = single_event

    def get_content(self, url, cache = None):
        if cache and os.path.exists(cache):
            print("Loading cache ({})".format(cache))
            with open(cache) as f:
                content = "\n".join(f.readlines())
        else:
            content = self.downloader.download(url)

            if cache:
                print("Saving cache ({})".format(cache))
                dir = os.path.dirname(cache)
                if dir != "" and not os.path.exists(dir):
                    os.makedirs(dir)
                with open(cache, "w") as text_file:
                    text_file.write(content)
        return content


    def process(self, url, url_human = None, cache = None, default_values = None, published = False):
        content = self.get_content(url, cache)

        if content is None:
            return None

        if self.extractor is not None:
            return self.extractor.extract(content, url, url_human, default_values, published)
        else:
            # if the extractor is not defined, use a list of default extractors
            for e in Extractor.get_default_extractors(self.single_event):
                #try:
                    events = e.extract(content, url, url_human, default_values, published)
                    if events is not None:
                        return events
                #except:
                #    continue
        return None

