from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
from django.urls import path, include, re_path
from django.contrib.auth import views as auth_views
from django.views.i18n import JavaScriptCatalog


from .views import *

urlpatterns = [
    path("", home, name="home"),
    path("semaine/<int:year>/<int:week>/", week_view, name='week_view'),
    path("mois/<int:year>/<int:month>/", month_view, name='month_view'),
    path("jour/<int:year>/<int:month>/<int:day>/", day_view, name='day_view'),
    path("aujourdhui/", day_view, name="aujourdhui"),
    path("cette-semaine/", week_view, name="cette_semaine"),
    path("ce-mois-ci", month_view, name="ce_mois_ci"),
    path("tag/<t>/", view_tag, name='view_tag'),
    path("tags/", tag_list, name='view_all_tags'),
    path("moderation/", moderation, name='moderation'),
    path("event/<int:year>/<int:month>/<int:day>/<int:pk>-<extra>", EventDetailView.as_view(), name="view_event"),
    path("event/<int:pk>/edit", EventUpdateView.as_view(), name="edit_event"),
    path("event/<int:pk>/change-status/<status>", change_status_event, name="change_status_event"),
    path("event/<int:pk>/delete", EventDeleteView.as_view(), name="delete_event"),
    path("event/<int:year>/<int:month>/<int:day>/<int:pk>/set_duplicate", set_duplicate, name="set_duplicate"),
    path("ajouter", import_from_url, name="add_event"),
    path("admin/", admin.site.urls),
    path('accounts/', include('django.contrib.auth.urls')),
    path("test_app/", include("test_app.urls")),
    path("static-content/create", StaticContentCreateView.as_view(), name="create_static_content"),
    path("static-content/<int:pk>/edit", StaticContentUpdateView.as_view(), name="edit_static_content"),
    path('rechercher', event_search, name='event_search'),
    path('rechercher/complet/', event_search_full, name='event_search_full'),
    path('mentions-legales', mentions_legales, name='mentions_legales'),
    path('contact', ContactMessageCreateView.as_view(), name='contact'),
    path('contactmessages', contactmessages, name='contactmessages'),
    path('contactmessage/<int:pk>', ContactMessageUpdateView.as_view(), name='contactmessage'),
    path("imports/", imports, name="imports"),
    path("imports/add", add_import, name="add_import"),
    path("imports/<int:pk>/cancel", cancel_import, name="cancel_import"),
    path("rimports/", recurrent_imports, name="recurrent_imports"),
    path("rimports/add", RecurrentImportCreateView.as_view(), name="add_rimport"),
    path("rimports/<int:pk>/view", view_rimport, name="view_rimport"),
    path("rimports/<int:pk>/edit", RecurrentImportUpdateView.as_view(), name="edit_rimport"),
    path("rimports/<int:pk>/delete", RecurrentImportDeleteView.as_view(), name="delete_rimport"),
    path("rimports/<int:pk>/run", run_rimport, name="run_rimport"),
    path("catrules/", categorisation_rules, name="categorisation_rules"),
    path("catrules/add", CategorisationRuleCreateView.as_view(), name="add_catrule"),
    path("catrules/<int:pk>/edit", CategorisationRuleUpdateView.as_view(), name="edit_catrule"),
    path("catrules/<int:pk>/delete", CategorisationRuleDeleteView.as_view(), name="delete_catrule"),
    path("catrules/apply", apply_categorisation_rules, name="apply_catrules"),
    path("duplicates/", duplicates, name="duplicates"),
    path("duplicates/<int:pk>", DuplicatedEventsDetailView.as_view(), name="view_duplicate"),
    path("duplicates/<int:pk>/fix", fix_duplicate, name="fix_duplicate"),
    path("duplicates/<int:pk>/merge", merge_duplicate, name="merge_duplicate"),
]

if settings.DEBUG:
    urlpatterns += staticfiles_urlpatterns()
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

# If you already have a js_info_dict dictionary, just add
# 'recurrence' to the existing 'packages' tuple.
js_info_dict = {
    'packages': ('recurrence', ),
}

# jsi18n can be anything you like here
urlpatterns += [ path('jsi18n.js', JavaScriptCatalog.as_view(packages=['recurrence']), name='jsi18n'), ]